@@ -27,7 +27,7 @@
 //
 
 using System;
-using NDesk.DBus;
+using DBus;
 
 using Banshee.ServiceStack;
 
@@ -38,5 +38,6 @@ namespace Banshee.Gui
     {
         void Present ();
         void Hide ();
+        void Fullscreen ();
     }
 }
